CharacteristicValue class

Value update for specific CharacteristicInstance.

Constructors

CharacteristicValue({required CharacteristicInstance characteristic, required Result<List<int>, GenericFailure<CharacteristicValueUpdateError>?> result})
const

Properties

characteristic → CharacteristicInstance
final
hashCode → int
The hash code for this object.
no setterinherited
result → Result<List<int>, GenericFailure<CharacteristicValueUpdateError>?>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited