connectToDevice method
Connects to a specific device and the connection remains established until
the stream is cancelled or the connection is closed by the peripheral.
The actual connection updates should be propagated to the connectionUpdateStream.
Implementation
Stream<void> connectToDevice(
String id,
Map<Uuid, List<Uuid>>? servicesWithCharacteristicsToDiscover,
Duration? connectionTimeout,
) {
throw UnimplementedError('connectToDevice has not been implemented.');
}