scanForDevices method
Stream that handles triggers scanning for Ble devices.
As long as the stream has been listened to the scanning continues. When
the stream is cancelled the ble scanning should stop.
Implementation
Stream<void> scanForDevices({
required List<Uuid> withServices,
required ScanMode scanMode,
required bool requireLocationServicesEnabled,
}) {
throw UnimplementedError('scanForDevices has not been implemented.');
}