writeCharacteristicWithResponse method
Perform writing a value to a specific characteristic and awaiting the acknowledgment from the peripheral.
When implement this operation on the platform make sure that you return a
response only when the peripheral acknowledged the write operation
Implementation
Future<WriteCharacteristicInfo> writeCharacteristicWithResponse(
CharacteristicInstance characteristic,
List<int> value,
) {
throw UnimplementedError(
'writeCharacteristicWithResponse has not been implemented.');
}