writeCharacteristicWithoutResponse method
Perform writing a value to a specific characteristic without awaiting the acknowledgment from the peripheral.
When implementing this operation on the platform make sure that it directly returns a response to the dart layer when the command arrived.
Implementation
Future<WriteCharacteristicInfo> writeCharacteristicWithoutResponse(
CharacteristicInstance characteristic,
List<int> value,
) {
throw UnimplementedError(
'writeCharacteristicWithoutResponse has not been implemented.');
}